diff --git a/doc/src/sgml/spgist.sgml b/doc/src/sgml/spgist.sgml
index 06b7519052..437b17c2ae 100644
--- a/doc/src/sgml/spgist.sgml
+++ b/doc/src/sgml/spgist.sgml
@@ -145,25 +145,21 @@
        <literal>&amp;&lt;|</literal>
        <literal>&lt;&lt;|</literal>
        <literal>|&gt;&gt;</literal>
        <literal>|&amp;&gt;</literal>
       </entry>
      </row>
      <row>
       <entry><literal>text_ops</literal></entry>
       <entry><type>text</type></entry>
       <entry>
-       <literal>&lt;</literal>
-       <literal>&lt;=</literal>
        <literal>=</literal>
-       <literal>&gt;</literal>
-       <literal>&gt;=</literal>
        <literal>~&lt;=~</literal>
        <literal>~&lt;~</literal>
        <literal>~&gt;=~</literal>
        <literal>~&gt;~</literal>
        <literal>^@</literal>
       </entry>
      </row>
      <row>
       <entry><literal>inet_ops</literal></entry>
       <entry><type>inet</type>, <type>cidr</type></entry>
@@ -185,20 +181,30 @@
    </tgroup>
   </table>
 
  <para>
   Of the two operator classes for type <type>point</type>,
   <literal>quad_point_ops</literal> is the default.  <literal>kd_point_ops</literal>
   supports the same operators but uses a different index data structure which
   may offer better performance in some applications.
  </para>
 
+ <warning>
+  <para>
+   Before PostgreSQL 11, the basic comparison operators <literal>&lt;</literal>,
+   <literal>&lt;=</literal>, <literal>&gt;</literal>, and <literal>&gt;=</literal>
+   were also supported by <acronym>SP-GiST</acronym> <literal>text_ops</literal>.
+   They may return wrong results in collation sensive cases hence should not
+   be used.
+  </para>
+ </warning>
+
 </sect1>
 
 <sect1 id="spgist-extensibility">
  <title>Extensibility</title>
 
  <para>
   <acronym>SP-GiST</acronym> offers an interface with a high level of
   abstraction, requiring the access method developer to implement only
   methods specific to a given data type. The <acronym>SP-GiST</acronym> core
   is responsible for efficient disk mapping and searching the tree structure.
diff --git a/src/include/catalog/pg_amop.dat b/src/include/catalog/pg_amop.dat
index b1cf8ec5fc..70b3789c36 100644
--- a/src/include/catalog/pg_amop.dat
+++ b/src/include/catalog/pg_amop.dat
@@ -1431,32 +1431,20 @@
   amopmethod => 'spgist' },
 { amopfamily => 'spgist/text_ops', amoplefttype => 'text',
   amoprighttype => 'text', amopstrategy => '3', amopopr => '=(text,text)',
   amopmethod => 'spgist' },
 { amopfamily => 'spgist/text_ops', amoplefttype => 'text',
   amoprighttype => 'text', amopstrategy => '4', amopopr => '~>=~(text,text)',
   amopmethod => 'spgist' },
 { amopfamily => 'spgist/text_ops', amoplefttype => 'text',
   amoprighttype => 'text', amopstrategy => '5', amopopr => '~>~(text,text)',
   amopmethod => 'spgist' },
-{ amopfamily => 'spgist/text_ops', amoplefttype => 'text',
-  amoprighttype => 'text', amopstrategy => '11', amopopr => '<(text,text)',
-  amopmethod => 'spgist' },
-{ amopfamily => 'spgist/text_ops', amoplefttype => 'text',
-  amoprighttype => 'text', amopstrategy => '12', amopopr => '<=(text,text)',
-  amopmethod => 'spgist' },
-{ amopfamily => 'spgist/text_ops', amoplefttype => 'text',
-  amoprighttype => 'text', amopstrategy => '14', amopopr => '>=(text,text)',
-  amopmethod => 'spgist' },
-{ amopfamily => 'spgist/text_ops', amoplefttype => 'text',
-  amoprighttype => 'text', amopstrategy => '15', amopopr => '>(text,text)',
-  amopmethod => 'spgist' },
 { amopfamily => 'spgist/text_ops', amoplefttype => 'text',
   amoprighttype => 'text', amopstrategy => '28', amopopr => '^@(text,text)',
   amopmethod => 'spgist' },
 
 # btree jsonb_ops
 { amopfamily => 'btree/jsonb_ops', amoplefttype => 'jsonb',
   amoprighttype => 'jsonb', amopstrategy => '1', amopopr => '<(jsonb,jsonb)',
   amopmethod => 'btree' },
 { amopfamily => 'btree/jsonb_ops', amoplefttype => 'jsonb',
   amoprighttype => 'jsonb', amopstrategy => '2', amopopr => '<=(jsonb,jsonb)',
diff --git a/src/test/regress/expected/create_index.out b/src/test/regress/expected/create_index.out
index fe5b698669..43f9242b03 100644
--- a/src/test/regress/expected/create_index.out
+++ b/src/test/regress/expected/create_index.out
@@ -305,74 +305,50 @@ SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcde';
 -------
      1
 (1 row)
 
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
  count 
 -------
      1
 (1 row)
 
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
- count 
--------
-   272
-(1 row)
-
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
  count 
 -------
    272
 (1 row)
 
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
- count 
--------
-   273
-(1 row)
-
 SELECT count(*) FROM radix_text_tbl WHERE t ~<=~ 'Aztec                         Ct  ';
  count 
 -------
    273
 (1 row)
 
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Aztec                         Ct  ';
  count 
 -------
      1
 (1 row)
 
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth                         St  ';
  count 
 -------
      2
 (1 row)
 
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
- count 
--------
-    50
-(1 row)
-
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
  count 
 -------
     50
 (1 row)
 
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
- count 
--------
-    48
-(1 row)
-
 SELECT count(*) FROM radix_text_tbl WHERE t ~>~  'Worth                         St  ';
  count 
 -------
     48
 (1 row)
 
 SELECT count(*) FROM radix_text_tbl WHERE t ^@  'Worth';
  count 
 -------
      2
@@ -1031,65 +1007,35 @@ SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
    ->  Index Only Scan using sp_radix_ind on radix_text_tbl
          Index Cond: (t = 'P0123456789abcdefF'::text)
 (3 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
  count 
 -------
      1
 (1 row)
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
-                              QUERY PLAN                              
-----------------------------------------------------------------------
- Aggregate
-   ->  Index Only Scan using sp_radix_ind on radix_text_tbl
-         Index Cond: (t < 'Aztec                         Ct  '::text)
-(3 rows)
-
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
- count 
--------
-   272
-(1 row)
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
                                QUERY PLAN                               
 ------------------------------------------------------------------------
  Aggregate
    ->  Index Only Scan using sp_radix_ind on radix_text_tbl
          Index Cond: (t ~<~ 'Aztec                         Ct  '::text)
 (3 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
  count 
 -------
    272
 (1 row)
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
-                              QUERY PLAN                               
------------------------------------------------------------------------
- Aggregate
-   ->  Index Only Scan using sp_radix_ind on radix_text_tbl
-         Index Cond: (t <= 'Aztec                         Ct  '::text)
-(3 rows)
-
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
- count 
--------
-   273
-(1 row)
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~<=~ 'Aztec                         Ct  ';
                                QUERY PLAN                                
 -------------------------------------------------------------------------
  Aggregate
    ->  Index Only Scan using sp_radix_ind on radix_text_tbl
          Index Cond: (t ~<=~ 'Aztec                         Ct  '::text)
 (3 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t ~<=~ 'Aztec                         Ct  ';
@@ -1121,65 +1067,35 @@ SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth
    ->  Index Only Scan using sp_radix_ind on radix_text_tbl
          Index Cond: (t = 'Worth                         St  '::text)
 (3 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth                         St  ';
  count 
 -------
      2
 (1 row)
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
-                              QUERY PLAN                               
------------------------------------------------------------------------
- Aggregate
-   ->  Index Only Scan using sp_radix_ind on radix_text_tbl
-         Index Cond: (t >= 'Worth                         St  '::text)
-(3 rows)
-
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
- count 
--------
-    50
-(1 row)
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
                                QUERY PLAN                                
 -------------------------------------------------------------------------
  Aggregate
    ->  Index Only Scan using sp_radix_ind on radix_text_tbl
          Index Cond: (t ~>=~ 'Worth                         St  '::text)
 (3 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
  count 
 -------
     50
 (1 row)
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
-                              QUERY PLAN                              
-----------------------------------------------------------------------
- Aggregate
-   ->  Index Only Scan using sp_radix_ind on radix_text_tbl
-         Index Cond: (t > 'Worth                         St  '::text)
-(3 rows)
-
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
- count 
--------
-    48
-(1 row)
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~>~  'Worth                         St  ';
                                QUERY PLAN                               
 ------------------------------------------------------------------------
  Aggregate
    ->  Index Only Scan using sp_radix_ind on radix_text_tbl
          Index Cond: (t ~>~ 'Worth                         St  '::text)
 (3 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t ~>~  'Worth                         St  ';
@@ -1607,71 +1523,37 @@ SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
          ->  Bitmap Index Scan on sp_radix_ind
                Index Cond: (t = 'P0123456789abcdefF'::text)
 (5 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
  count 
 -------
      1
 (1 row)
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
-                                 QUERY PLAN                                 
-----------------------------------------------------------------------------
- Aggregate
-   ->  Bitmap Heap Scan on radix_text_tbl
-         Recheck Cond: (t < 'Aztec                         Ct  '::text)
-         ->  Bitmap Index Scan on sp_radix_ind
-               Index Cond: (t < 'Aztec                         Ct  '::text)
-(5 rows)
-
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
- count 
--------
-   272
-(1 row)
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
                                   QUERY PLAN                                  
 ------------------------------------------------------------------------------
  Aggregate
    ->  Bitmap Heap Scan on radix_text_tbl
          Recheck Cond: (t ~<~ 'Aztec                         Ct  '::text)
          ->  Bitmap Index Scan on sp_radix_ind
                Index Cond: (t ~<~ 'Aztec                         Ct  '::text)
 (5 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
  count 
 -------
    272
 (1 row)
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
-                                 QUERY PLAN                                  
------------------------------------------------------------------------------
- Aggregate
-   ->  Bitmap Heap Scan on radix_text_tbl
-         Recheck Cond: (t <= 'Aztec                         Ct  '::text)
-         ->  Bitmap Index Scan on sp_radix_ind
-               Index Cond: (t <= 'Aztec                         Ct  '::text)
-(5 rows)
-
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
- count 
--------
-   273
-(1 row)
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~<=~ 'Aztec                         Ct  ';
                                   QUERY PLAN                                   
 -------------------------------------------------------------------------------
  Aggregate
    ->  Bitmap Heap Scan on radix_text_tbl
          Recheck Cond: (t ~<=~ 'Aztec                         Ct  '::text)
          ->  Bitmap Index Scan on sp_radix_ind
                Index Cond: (t ~<=~ 'Aztec                         Ct  '::text)
 (5 rows)
@@ -1709,71 +1591,37 @@ SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth
          ->  Bitmap Index Scan on sp_radix_ind
                Index Cond: (t = 'Worth                         St  '::text)
 (5 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth                         St  ';
  count 
 -------
      2
 (1 row)
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
-                                 QUERY PLAN                                  
------------------------------------------------------------------------------
- Aggregate
-   ->  Bitmap Heap Scan on radix_text_tbl
-         Recheck Cond: (t >= 'Worth                         St  '::text)
-         ->  Bitmap Index Scan on sp_radix_ind
-               Index Cond: (t >= 'Worth                         St  '::text)
-(5 rows)
-
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
- count 
--------
-    50
-(1 row)
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
                                   QUERY PLAN                                   
 -------------------------------------------------------------------------------
  Aggregate
    ->  Bitmap Heap Scan on radix_text_tbl
          Recheck Cond: (t ~>=~ 'Worth                         St  '::text)
          ->  Bitmap Index Scan on sp_radix_ind
                Index Cond: (t ~>=~ 'Worth                         St  '::text)
 (5 rows)
 
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
  count 
 -------
     50
 (1 row)
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
-                                 QUERY PLAN                                 
-----------------------------------------------------------------------------
- Aggregate
-   ->  Bitmap Heap Scan on radix_text_tbl
-         Recheck Cond: (t > 'Worth                         St  '::text)
-         ->  Bitmap Index Scan on sp_radix_ind
-               Index Cond: (t > 'Worth                         St  '::text)
-(5 rows)
-
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
- count 
--------
-    48
-(1 row)
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~>~  'Worth                         St  ';
                                   QUERY PLAN                                  
 ------------------------------------------------------------------------------
  Aggregate
    ->  Bitmap Heap Scan on radix_text_tbl
          Recheck Cond: (t ~>~ 'Worth                         St  '::text)
          ->  Bitmap Index Scan on sp_radix_ind
                Index Cond: (t ~>~ 'Worth                         St  '::text)
 (5 rows)
diff --git a/src/test/regress/expected/opr_sanity.out b/src/test/regress/expected/opr_sanity.out
index a1e18a6ceb..6e59fcac26 100644
--- a/src/test/regress/expected/opr_sanity.out
+++ b/src/test/regress/expected/opr_sanity.out
@@ -1863,40 +1863,36 @@ ORDER BY 1, 2, 3;
        4000 |            4 | ~>=~
        4000 |            5 | >>
        4000 |            5 | ~>~
        4000 |            6 | -|-
        4000 |            6 | ~=
        4000 |            7 | @>
        4000 |            8 | <@
        4000 |            9 | &<|
        4000 |           10 | <<|
        4000 |           10 | <^
-       4000 |           11 | <
        4000 |           11 | >^
        4000 |           11 | |>>
-       4000 |           12 | <=
        4000 |           12 | |&>
-       4000 |           14 | >=
-       4000 |           15 | >
        4000 |           16 | @>
        4000 |           18 | =
        4000 |           19 | <>
        4000 |           20 | <
        4000 |           21 | <=
        4000 |           22 | >
        4000 |           23 | >=
        4000 |           24 | <<
        4000 |           25 | <<=
        4000 |           26 | >>
        4000 |           27 | >>=
        4000 |           28 | ^@
-(122 rows)
+(118 rows)
 
 -- Check that all opclass search operators have selectivity estimators.
 -- This is not absolutely required, but it seems a reasonable thing
 -- to insist on for all standard datatypes.
 SELECT p1.amopfamily, p1.amopopr, p2.oid, p2.oprname
 FROM pg_amop AS p1, pg_operator AS p2
 WHERE p1.amopopr = p2.oid AND p1.amoppurpose = 's' AND
     (p2.oprrest = 0 OR p2.oprjoin = 0);
  amopfamily | amopopr | oid | oprname 
 ------------+---------+-----+---------
diff --git a/src/test/regress/sql/create_index.sql b/src/test/regress/sql/create_index.sql
index f7731265a0..2b24747c44 100644
--- a/src/test/regress/sql/create_index.sql
+++ b/src/test/regress/sql/create_index.sql
@@ -197,38 +197,30 @@ SELECT count(*) FROM quad_point_tbl WHERE p <^ '(5000, 4000)';
 SELECT count(*) FROM quad_point_tbl WHERE p >^ '(5000, 4000)';
 
 SELECT count(*) FROM quad_point_tbl WHERE p ~= '(4585, 365)';
 
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdef';
 
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcde';
 
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
 
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
-
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
 
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
-
 SELECT count(*) FROM radix_text_tbl WHERE t ~<=~ 'Aztec                         Ct  ';
 
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Aztec                         Ct  ';
 
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth                         St  ';
 
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
-
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
 
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
-
 SELECT count(*) FROM radix_text_tbl WHERE t ~>~  'Worth                         St  ';
 
 SELECT count(*) FROM radix_text_tbl WHERE t ^@  'Worth';
 
 SELECT * FROM gpolygon_tbl ORDER BY f1 <-> '(0,0)'::point LIMIT 10;
 
 SELECT circle_center(f1), round(radius(f1)) as radius FROM gcircle_tbl ORDER BY f1 <-> '(200,300)'::point LIMIT 10;
 
 -- Now check the results from plain indexscan
 SET enable_seqscan = OFF;
@@ -396,56 +388,40 @@ SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdef';
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdef';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcde';
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcde';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~<=~ 'Aztec                         Ct  ';
 SELECT count(*) FROM radix_text_tbl WHERE t ~<=~ 'Aztec                         Ct  ';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Aztec                         Ct  ';
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Aztec                         Ct  ';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth                         St  ';
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth                         St  ';
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~>~  'Worth                         St  ';
 SELECT count(*) FROM radix_text_tbl WHERE t ~>~  'Worth                         St  ';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ^@	 'Worth';
 SELECT count(*) FROM radix_text_tbl WHERE t ^@	 'Worth';
 
 EXPLAIN (COSTS OFF)
 SELECT * FROM gpolygon_tbl ORDER BY f1 <-> '(0,0)'::point LIMIT 10;
@@ -537,56 +513,40 @@ SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdef';
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdef';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcde';
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcde';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
 SELECT count(*) FROM radix_text_tbl WHERE t = 'P0123456789abcdefF';
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
-SELECT count(*) FROM radix_text_tbl WHERE t <    'Aztec                         Ct  ';
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
 SELECT count(*) FROM radix_text_tbl WHERE t ~<~  'Aztec                         Ct  ';
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
-SELECT count(*) FROM radix_text_tbl WHERE t <=   'Aztec                         Ct  ';
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~<=~ 'Aztec                         Ct  ';
 SELECT count(*) FROM radix_text_tbl WHERE t ~<=~ 'Aztec                         Ct  ';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Aztec                         Ct  ';
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Aztec                         Ct  ';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth                         St  ';
 SELECT count(*) FROM radix_text_tbl WHERE t =    'Worth                         St  ';
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
-SELECT count(*) FROM radix_text_tbl WHERE t >=   'Worth                         St  ';
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
 SELECT count(*) FROM radix_text_tbl WHERE t ~>=~ 'Worth                         St  ';
 
-EXPLAIN (COSTS OFF)
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
-SELECT count(*) FROM radix_text_tbl WHERE t >    'Worth                         St  ';
-
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ~>~  'Worth                         St  ';
 SELECT count(*) FROM radix_text_tbl WHERE t ~>~  'Worth                         St  ';
 
 EXPLAIN (COSTS OFF)
 SELECT count(*) FROM radix_text_tbl WHERE t ^@	 'Worth';
 SELECT count(*) FROM radix_text_tbl WHERE t ^@	 'Worth';
 
 RESET enable_seqscan;
 RESET enable_indexscan;
